@@ -164,7 +164,7 @@ class TrackSegmentFinderLUT5:
             hits = self._check_layer_hit(layer_in,edge_hit)
             (seg_id_list,row_id_list,col_id_list) = numpy.nonzero(hits)
             for seg_id,row_id,col_id in zip(seg_id_list,row_id_list,col_id_list):
-                layer_segments[seg_id,0+row_id*4,j] = 1
+                layer_segments[seg_id,0+row_id*4,col_id] = 1
         return self._frame_out
 
 
@@ -206,11 +206,11 @@ class TrackSegmentFinderLUT5:
                         layer_segments[seg_id,1,14] = 1
                         layer_segments[seg_id,1,15] = 1
                     else:
-                        layer_segments[seg_id,0,j-1] = 1
-                        layer_segments[seg_id,0,j] = 1
-                        layer_segments[seg_id,0,j+1] = 1
-                        layer_segments[seg_id,1,j-1] = 1
-                        layer_segments[seg_id,1,j] = 1
+                        layer_segments[seg_id,0,col_id-1] = 1
+                        layer_segments[seg_id,0,col_id] = 1
+                        layer_segments[seg_id,0,col_id+1] = 1
+                        layer_segments[seg_id,1,col_id-1] = 1
+                        layer_segments[seg_id,1,col_id] = 1
                 else:
                     if(col_id == 0):
                         layer_segments[seg_id-1,4,15] = 1
@@ -225,11 +225,11 @@ class TrackSegmentFinderLUT5:
                         layer_segments[seg_id,3,14] = 1
                         layer_segments[seg_id,3,15] = 1
                     else:
-                        layer_segments[seg_id,4,j-1] = 1
+                        layer_segments[seg_id,4,col_id-1] = 1
                         layer_segments[seg_id,4,j] = 1
-                        layer_segments[seg_id,4,j+1] = 1
-                        layer_segments[seg_id,3,j-1] = 1
-                        layer_segments[seg_id,3,j] = 1
+                        layer_segments[seg_id,4,col_id+1] = 1
+                        layer_segments[seg_id,3,col_id-1] = 1
+                        layer_segments[seg_id,3,col_id] = 1
         return self._frame_out
 
     def _detect_hw_model(self,frame_in,edge_hit=True):
